#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import argparse
from pathlib import Path

from subprocess_util.chunked_transfer.active_receive.exec_receive_chunks_active import exec_receive_chunks_active


def main():
    args = parse_args()
    #
    ssh_source: str = args.ssh_source
    source_chunk_dir: Path = args.source_chunk_dir
    target_chunk_dir: Path = args.chunk_dir
    target_path: Path = args.target_path

    target_path.parent.mkdir(parents=True, exist_ok=True)

    command = ['btrfs', 'receive', str(target_path.parent)]

    exec_receive_chunks_active(
        command,
        ssh_source,
        source_chunk_dir,
        target_chunk_dir,
    )


def parse_args():
    parser = argparse.ArgumentParser(prog='btrfs-receive-chunks')

    parser.add_argument('--chunk-dir',
                        help='Chunks are saved in this directory. '
                             'Defaults to parent directory of SUBVOLUME.',
                        dest='chunk_dir',
                        type=Path,
                        metavar='CHUNK_DIR',
                        default=None,
                        )

    parser.add_argument('ssh_source',
                        help='Hostname of source computer; as configured in ~/.ssh/config.',
                        metavar='SSH_SOURCE'
                        )

    parser.add_argument('source_chunk_dir',
                        help='Chunks are saved in this directory on SSH_SOURCE. '
                             'Must be an absolute path.',
                        type=Path,
                        metavar='SOURCE_CHUNK_DIR',
                        )

    parser.add_argument('target_path',
                        help='Path where the subvolume will be created. '
                             'The last component of the path '
                             'must be equal to the name of the subvolume on the sending side.',
                        type=Path,
                        metavar='SUBVOLUME'
                        )

    args = parser.parse_args()

    # Make all paths absolute. Set default values.
    args.target_path = args.target_path.absolute()
    if args.chunk_dir:
        args.chunk_dir = args.chunk_dir.absolute()
    else:
        args.chunk_dir = args.target_path.absolute().parent
    if not args.source_chunk_dir.is_absolute():
        raise ValueError(f'SOURCE_CHUNK_DIR must be absolute')

    return args


if __name__ == '__main__':
    main()
