#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import argparse
from pathlib import Path

from subprocess_util.chunked_transfer.active_receive.exec_send_chunks_passive import exec_send_chunks_passive


def main():
    args = parse_args()
    #
    chunk_size = args.chunk_size
    compressed_data: bool = args.compressed_data
    child: Path = args.child
    parent: Path | None = args.parent
    source_chunk_dir: Path = args.chunk_dir

    source_chunk_dir.mkdir(parents=True, exist_ok=True)

    command_parts = (
        ['btrfs', 'send'],
        ['-p', str(parent)] if parent else [],
        ['--compress-data'] if compressed_data else [],
        [str(child)]
    )
    command = [x for xs in command_parts for x in xs]
    returncode = exec_send_chunks_passive(
        command,
        source_chunk_dir,
        chunk_size,
    )
    exit(returncode)


def parse_args():
    parser = argparse.ArgumentParser(prog='btrfs-send-chunks')

    parser.add_argument('-p',
                        help='Path to parent subvolume; forwarded to btrfs-send.',
                        dest='parent',
                        default=None,
                        type=Path,
                        metavar='PARENT_SUBVOLUME'
                        )

    parser.add_argument('--compressed-data',
                        help='Forwarded to btrfs-send.',
                        dest='compressed_data',
                        action='store_true',
                        default=False,
                        )

    parser.add_argument('--chunk-size',
                        help='Size in bytes; defaults to 128 MB.',
                        dest='chunk_size',
                        type=int,
                        default=128 * 1024 * 1024,
                        )

    parser.add_argument('--chunk-dir',
                        help='Chunks are saved in this directory. '
                             'Defaults to parent directory of CHILD.',
                        dest='chunk_dir',
                        type=Path,
                        metavar='CHUNK_DIR',
                        default=None,
                        )

    parser.add_argument('child',
                        help='Path to child subvolume. Forwarded to btrfs-send.',
                        type=Path,
                        metavar='CHILD_SUBVOLUME'
                        )

    args = parser.parse_args()

    # Make all paths absolute. Set default values.
    args.child = args.child.absolute()
    #
    if args.chunk_dir:
        args.chunk_dir = args.chunk_dir.absolute()
    else:  # Default value
        args.chunk_dir = args.child.absolute().parent
    #
    if args.parent:
        args.parent = args.parent.absolute()

    return args


if __name__ == '__main__':
    main()
